---
title: <span class="badge builder"></span> AnnotationPermission
---
# <span class="badge builder"></span> AnnotationPermission

## Constructor

```python
AnnotationPermission()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.AnnotationPermission
```

### <span class="badge object-method"></span> dashboard_permissions

```python
def dashboard_permissions(dashboard: cogbuilder.Builder[dashboard.AnnotationActions]) -> typing.Self
```

### <span class="badge object-method"></span> organization_permissions

```python
def organization_permissions(organization: cogbuilder.Builder[dashboard.AnnotationActions]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [AnnotationPermission](./object-AnnotationPermission.md)
